//功能：AIP650初始化和显示
module DH_AIP650_CTRL(
       input         clk1M,
		 input         rst_n,
		 input [2:0]   brightness,//数码管的亮度，一共8个级别
		 input [3:0]   SEG1,//SEG1显示的数字，8421BCD码
		 input [3:0]   SEG2,//SEG2显示的数字，8421BCD码
		 input [3:0]   SEG3,//SEG3显示的数字，8421BCD码
		 input [3:0]   SEG4,//SEG4显示的数字，8421BCD码
		 input [3:0]   DP,//SEG1-SEG4的小数点，高有效 DP[0]~SEG1 DP[3]~SEG4
		 input [3:0]   SEG_EN,//SEG1-SEG4是否显示 高有效 DP[0]~SEG1 DP[3]~SEG4
		 input         aip650_port_ready, 
		 output        ovalid,
		 output reg [15:0] cmd
		 
);
assign ovalid = 1'b1;
reg [2:0] cmd_cnt;
wire [6:0] hex1,hex2,hex3,hex4;
wire [3:0] brightness_w;
assign brightness_w = brightness+4'b0001;
always@(posedge clk1M or negedge rst_n)
begin
if(rst_n == 1'b0)
    begin
	 cmd <= {8'h48,1'b0,brightness_w[2:0],4'b0001};
	 end
else
    begin
	 cmd_cnt <= aip650_port_ready?((cmd_cnt >= 3'd4)?3'd0:cmd_cnt+3'd1):cmd_cnt;//cmd_cnt 从0-4循环
	 case(cmd_cnt)
	 3'd0:cmd <= {8'h48,1'b0,brightness_w[2:0],4'b0001};
	 3'd1:cmd <= {8'h68,DP[0] & SEG_EN[0],~hex1 & {7{SEG_EN[0]}}};
	 3'd2:cmd <= {8'h6A,DP[1] & SEG_EN[1],~hex2 & {7{SEG_EN[1]}}};
	 3'd3:cmd <= {8'h6C,DP[2] & SEG_EN[2],~hex3 & {7{SEG_EN[2]}}};
	 3'd4:cmd <= {8'h6E,DP[3] & SEG_EN[3],~hex4 & {7{SEG_EN[3]}}};
	 default:;
	 endcase
	 end
end
BCD2HEX u_BCD2HEX_0(
       .SEG(SEG1),
		 .HEX(hex1)
);
BCD2HEX u_BCD2HEX_1(
       .SEG(SEG2),
		 .HEX(hex2)
);
BCD2HEX u_BCD2HEX_2(
       .SEG(SEG3),
		 .HEX(hex3)
);
BCD2HEX u_BCD2HEX_3(
       .SEG(SEG4),
		 .HEX(hex4)
);
endmodule

module BCD2HEX(
       input [3:0] SEG,
		 output reg [6:0] HEX
);
always@(*)
begin
case(SEG)
       4'h0:HEX=7'b1000000;
       4'h1:HEX=7'b1111001;
       4'h2:HEX=7'b0100100;
       4'h3:HEX=7'b0110000;
       4'h4:HEX=7'b0011001;
       4'h5:HEX=7'b0010010;
       4'h6:HEX=7'b0000010;
       4'h7:HEX=7'b1111000;
       4'h8:HEX=7'b0000000;
       4'h9:HEX=7'b0010000;
		 4'ha:HEX=7'b0001000;
		 4'hb:HEX=7'b0000011;
		 4'hc:HEX=7'b1000110;
		 4'hd:HEX=7'b0100001;
		 4'he:HEX=7'b0000110;
		 4'hf:HEX=7'b0001110;
		 default:HEX = 7'b0111111;
endcase
end
endmodule 