//功能：实现AIP650四位数码管控制芯片的仿I2C时序
module DH_AIP650_PORT(
       input        clk1M,//最大频率：
		 input        rst_n,
		 input [15:0] icmd,//输入指令
		 input        ivalid,//输入指令有效标志，高有效
		 output       ready,
		 output       sclk,
		 inout        sda
);
localparam IDLE = 1'b0;
localparam SEND = 1'b1;
reg sclk_r;
reg sclk_reg;//clk1M的2分频
reg state;
reg iolink;//0：输入 1：输出
reg sda_r;
reg [15:0] cmd_r;//寄存输入的命令并作为移位寄存器使用
reg [5:0] bit_cnt;
assign sclk  = sclk_r;
assign sda   = iolink?sda_r:1'bz;
assign ready = !state;
always@(posedge clk1M or negedge rst_n)
begin
if(rst_n == 1'b0)
    begin
	 sclk_reg <= 1'b1;
	 state    <= IDLE;
	 iolink   <= 1'b1;//默认sda为输出
	 sda_r    <= 1'b1;//sda默认高电平
	 cmd_r    <= 16'd0;
	 bit_cnt  <= 6'd0;
	 end
else
    begin
	 case(state)
	 IDLE:begin
	     state <= ivalid?SEND:IDLE;
		  cmd_r <= ivalid?icmd:16'd0;
		  sclk_reg <= 1'b1;
		  sda_r    <= 1'b1;//sda默认高电平
		  bit_cnt  <= 6'd0;
	 end
	 SEND:begin
	     bit_cnt  <= bit_cnt+6'd1;
		  sclk_reg <= !bit_cnt[0] || (bit_cnt[5:1] >= 5'd19);
		  state    <= (bit_cnt[5:1] == 5'd20 && bit_cnt[0] == 1'b0)?IDLE:SEND;
		  if(bit_cnt[0] == 1'b0)
		      begin
				if(bit_cnt[5:1] == 5'd0)
				    begin
					 sda_r    <= 1'b0;//开始位
					 iolink   <= 1'b1;
					 end
			   else if(bit_cnt[5:1] == 5'd9)
				    begin
					 sda_r    <= 1'b0;//ACK
					 iolink   <= 1'b0;//此时sda位输入高阻态
					 end
				else if(bit_cnt[5:1] == 5'd18)
				    begin
					 sda_r    <= 1'b0;//ACK
					 iolink   <= 1'b0;//此时sda位输入高阻态
					 end
				else if(bit_cnt[5:1] == 5'd19)
				    begin
					 sda_r    <= 1'b0;//最后一个ACK后sda输出一个低电平以方便后面产生sda由低到高的停止位产生
					 iolink   <= 1'b1;//sda输出
					 end
				else if(bit_cnt[5:1] == 5'd20)
				    begin
					 sda_r    <= 1'b1;//最停止位产生
					 iolink   <= 1'b1;//sda输出
					 end
				else
				    begin
					 sda_r    <= cmd_r[15];
					 iolink   <= 1'b1;//sda输出
					 cmd_r    <= cmd_r<<1;
					 end
				end
	 end
	 endcase
	 end
end
always@(negedge clk1M or negedge rst_n)
begin
if(rst_n == 1'b0)
    sclk_r <= 1'b1;
else
    sclk_r <= sclk_reg;
end
endmodule 